#!/bin/sh

echo "This script will generate a tarball for you convinience"

if ! test -f "$1"; then
  echo
  echo "ERROR: ERROR:"
  echo "  Can't build module using $1 - file not found"
  echo 
  exit 1
fi

# Get the modulename
MODULENAME=`basename $1 .fec`
MODULEVERSION=`ferite-config --version`
BUILDER=`which builder`

# Get the directory we are going to build the tarball in
if test -d "$MODULENAME"; then
  echo "Cleaning old $MODULENAME directory away..."
  rm -rf $MODULENAME
fi

echo "Building Directory..."
mkdir $MODULENAME

# Copy over the skelton tree
echo "Copying skeleton files over..."
cp -rf skel/* $MODULENAME/

# Make the directory for the module
mkdir $MODULENAME/modules/$MODULENAME

# Copy the .fec file over
cp $1 $MODULENAME/modules/$MODULENAME

# Build the modules's c files
echo "Generating C files..."
cd $MODULENAME/modules/$MODULENAME
builder -m $MODULENAME $MODULENAME".fec"
cd ../../

# Now we sed modify the configure.ac configure.in and modules/Makefile.am
echo "Modifying configuration scripts..."
cat configure.ac.stub | sed -e "s/%mod%/$MODULENAME/g" > configure.ac
rm configure.ac.stub

cat configure.in.stub | sed -e "s/%mod%/$MODULENAME/g" > configure.in
rm configure.in.stub

cat modules/Makefile.am.stub | sed -e "s/%mod%/$MODULENAME/g" > modules/Makefile.am
rm modules/Makefile.am.stub

cat modules/$MODULENAME/Makefile.am | sed -e "s/-L\${top_builddir}\/src//g" > modules/$MODULENAME/Makefile.am.new
rm modules/$MODULENAME/Makefile.am
mv modules/$MODULENAME/Makefile.am.new modules/$MODULENAME/Makefile.am

case "$2" in
  tarball)
     echo "Building tarball..."
	 echo "  Running autotools"
     autoheader
	 aclocal
	 automake --foreign --add-missing
	 autoconf
	 echo "  Building tar archive"
	 cd ..
	 tar -cf $MODULENAME-$MODULEVERSION.tar $MODULENAME
	 echo "  Compressing"
	 gzip $MODULENAME-$MODULEVERSION.tar
	 echo "  Removing directory"
	 rm -rf $MODULENAME
	 ;;
   test)
     echo "Testing tree"
	 echo "  Running autotools"
     autoheader
	 aclocal
	 automake --foreign --add-missing
	 autoconf
	 echo "  Configuring"
	 ./configure
	 echo "  Building"
	 make
	 ;;
   *)
     ;;
esac
